import 'dart:convert';

import 'package:flutter/material.dart';
import 'package:flutter_inappwebview/flutter_inappwebview.dart';
import 'package:flutter_threatmetrix_module/flutter_threatmetrix_module.dart';

class WebviewContainer extends StatelessWidget {
  WebviewContainer({Key? key, required this.url}) : super(key: key);

  final String url;
  final GlobalKey webViewKey = GlobalKey();
  final _flutterThreatmetrixModulePlugin = FlutterThreatmetrixModule();

  InAppWebViewController? webViewController;
  InAppWebViewSettings settings =
      InAppWebViewSettings(javaScriptEnabled: true, geolocationEnabled: true);

  @override
  Widget build(BuildContext context) {
    return Scaffold(
      appBar: AppBar(
        title: const Text('Webview Example'),
      ),
      body: SizedBox(
        width: double.infinity,
        // the most important part of this example
        child: InAppWebView(
          key: webViewKey,
          // initialUrlRequest: URLRequest(url: WebUri('https://flutter.dev')),
          onWebViewCreated: (InAppWebViewController controller) async {
            if (await WebViewFeature.isFeatureSupported(
                WebViewFeature.WEB_MESSAGE_LISTENER)) {
              await controller.addWebMessageListener(WebMessageListener(
                jsObjectName: "PayDala",
                allowedOriginRules: {"*"},
                onPostMessage:
                    (message, sourceOrigin, isMainFrame, replyProxy) {
                  print(message);
                  print(message?.data);
                  var data = jsonDecode(message?.data);
                  print(data);
                  if(message?.data?.type == 'closePaydala'){
                    Navigator.pop(context);
                  }
                },
              ));
            }
            await controller.loadUrl(urlRequest: URLRequest(url: WebUri(url)));
          },
          onLoadStart: (InAppWebViewController controller, Uri? url) {
            print('onLoadStart $url');
          },

          onLoadStop: (InAppWebViewController controller, Uri? url) async {
            print('onLoadStop $url');
          },
          onProgressChanged: (InAppWebViewController controller, int progress) {
            print('onProgressChanged $progress');
          },
          onGeolocationPermissionsShowPrompt:
              (InAppWebViewController controller, String origin) async {
            return GeolocationPermissionShowPromptResponse(
                origin: origin, allow: true, retain: true);
          },
          onConsoleMessage: (controller, consoleMessage) {
            print("console message: ${consoleMessage.message}");
          },
        ),
      ),
    );
  }

  Future<void> getProfilingData(String sessionId) async {
    String profileData = 'No Data';
    String? error;
    String orgId = '52whdrrv';
    String fpServer = 'h-sdk.online-metrix.net';

    try {
      final result = await FlutterThreatmetrixModule()
              .getProfilingData(sessionId, orgId, fpServer) ??
          'No Data';
      profileData = result;
    } catch (e) {
      error = e.toString();
    }
  }
}
